##  Overview
Activate an optional extension to view SAP suggestions for AI agents and applications in reports. This enables you to identify optimization opportunities, expand the relevance of existing SAP solutions, and plan further projects or initiatives.
You can create fact sheets from relevant suggestions, which helps you complete your inventory.
